//
//  UIImageViewCached.m
//  UIImageViewCached
//
//  Created by Jaanus Kase on 09.04.11.
//  Copyright 2011 __MyCompanyName__. All rights reserved.
//

#import "UIImageView+Cached.h"
#import "ASIHTTPRequest.h"
#import "ASIDownloadCache.h"
#import <QuartzCore/QuartzCore.h>

@implementation UIImageView (Cached)

- (void) loadImageFromUrl:(NSURL *)url scale:(CGFloat)scale spinner:(BOOL)showSpinner {
    
    ASIDownloadCache *downloadCache = [ASIDownloadCache sharedCache];
	NSData *cachedData = [downloadCache cachedResponseDataForURL:url];

	if (cachedData) {
		
		// Just use the cached data to avoid any delay in showing the image.
		self.image = [UIImage imageWithCGImage:[UIImage imageWithData:cachedData].CGImage scale:scale orientation:UIImageOrientationUp];

	} else {
		
		UIActivityIndicatorView *spinner = nil;
		
		if (showSpinner) {
			
			spinner = [[[UIActivityIndicatorView alloc] initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleGray] autorelease];
			spinner.center = CGPointMake(self.bounds.size.width/2, self.bounds.size.height/2);
			[self addSubview:spinner];
			[spinner startAnimating];
		}
		
		// Actually do the download, async.
		dispatch_async(dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_DEFAULT, 0), ^{
			
			ASIHTTPRequest *request = [ASIHTTPRequest requestWithURL:url];
			
			[request setDownloadCache:downloadCache];
			[request setCacheStoragePolicy:ASICachePermanentlyCacheStoragePolicy];
			[request setCachePolicy:ASIAskServerIfModifiedWhenStaleCachePolicy|ASIFallbackToCacheIfLoadFailsCachePolicy];
			
			[request startSynchronous];
			NSError *error = [request error];
			if (!error) {
				dispatch_async(dispatch_get_main_queue(), ^{
					self.image = [UIImage imageWithCGImage:[UIImage imageWithData:[request responseData]].CGImage scale:scale orientation:UIImageOrientationUp];

					// Add image transition animation. http://stackoverflow.com/questions/2834573/how-to-animate-the-change-of-image-in-an-uiimageview
					CATransition *transition = [CATransition animation];
					transition.duration = 0.25;
					transition.timingFunction = [CAMediaTimingFunction functionWithName:kCAMediaTimingFunctionEaseInEaseOut];
					transition.type = kCATransitionFade;
					[self.layer addAnimation:transition forKey:nil];
				});
			}
			
			if (spinner) {
				[spinner removeFromSuperview];
			}
		});
	}
}

@end
